// java wrapper for vtkTypeUInt32Array object
//

package vtk;
import vtk.*;

public class vtkTypeUInt32Array extends vtkUnsignedIntArray
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long FastDownCast_2(vtkAbstractArray id0);
  public vtkTypeUInt32Array FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_2(id0);

    if (temp == 0) return null;
    return (vtkTypeUInt32Array)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTypeUInt32Array() { super(); }

  public vtkTypeUInt32Array(long id) { super(id); }
  public native long   VTKInit();

}
